@@ -7,14 +7,14 @@ from griffe import cli
 
 def test_main():
     """Basic CLI test."""
-    assert cli.main(["griffe"]) == 0
+    assert cli.main(["griffe", "-s", "src"]) == 0
 
 
 def test_show_help(capsys):
     """
     Show help.
 
-    Arguments:
+    Parameters:
         capsys: Pytest fixture to capture output.
     """
     with pytest.raises(SystemExit):
